@@ -4,8 +4,8 @@ module Bundler
   # Represents metadata from when the Bundler gem was built.
   module BuildMetadata
     # begin ivars
-    @built_at = "2019-06-13".freeze
-    @git_commit_sha = "496bca538".freeze
+    @built_at = "2019-12-20".freeze
+    @git_commit_sha = "4da3289ebd".freeze
     @release = true
     # end ivars
 
@@ -25,7 +25,7 @@ module Bundler
 
     # The SHA for the git commit the bundler gem was built from.
     def self.git_commit_sha
-      return @git_commit_sha if @git_commit_sha
+      return @git_commit_sha if instance_variable_defined? :@git_commit_sha
 
       # If Bundler has been installed without its .git directory and without a
       # commit instance variable then we can't determine its commits SHA.
